Some useful django widgets
==========================

``djeu`` is a collection of the widgets

Components
----------

- DatePickerInput
- LinkedFileInput
- PdfViewer

Requirements
------------

::

    Django>=3.2


Optional Requirements
---------------------

::

    django-static-jquery-ui>=1.12.1.1

Usage
=====

